camelot.camelot.view.forms

Package camelot :: Package camelot :: Package view :: Module forms |
[hide private]
[frames] | no frames]

# Module forms

source code

Python structures to represent interface forms.

These structures can be transformed to QT forms.

Classes | [hide private]
| Form Use the QFormLayout widget to render a form
| TabForm Render forms within a QTabWidget
| HBoxForm Render different forms in a horizontal box
| VBoxForm Render different forms or widgets in a vertical box
| WidgetOnlyForm Renders a single widget without its label, typically a one2many widget

Functions | [hide private]
structure_to_form(structure) Convert a python data structure to a form, using the following rules : | source code

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.forms')`

Function Details | [hide private]

### structure_to_form(structure) | source code
Convert a python data structure to a form, using the following rules : if structure is an instance of Form, return structure if structure is a list, create a Form from this list